import 'package:flutter/cupertino.dart';
import 'package:provider/provider.dart';
import 'package:thesis_shop/models/product.dart';
import 'package:thesis_shop/models/remote_resource.dart';
import 'package:thesis_shop/store/product_loading_store.dart';
import 'package:thesis_shop/store/user_store.dart';

class ProductStore {
  final RemoteResource<List<Product>> products;

  const ProductStore(this.products);
  factory ProductStore.fromProductLoadingStore(
          ProductLoadingStore productLoadingStore) =>
      ProductStore(productLoadingStore.products);
}

class ProductStoreProvider
    extends ProxyProvider2<UserStore, ProductLoadingStore, ProductStore> {
  ProductStoreProvider({Key? key, Widget? child})
      : super(key: key, child: child, update: _combineStores);

  static ProductStore _combineStores(BuildContext context, UserStore userStore,
      ProductLoadingStore productLoadingStore, ProductStore? oldStore) {
    if (!userStore.isSignedIn) {
      return ProductStore.fromProductLoadingStore(productLoadingStore);
    }
    final remoteProducts = productLoadingStore.products.mapIfFinished(
      (products) =>
          products.map((product) => product.copyWithDiscount()).toList(),
    );
    return ProductStore(remoteProducts);
  }
}
